@@ -6,6 +6,7 @@
 MainWidget::MainWidget(QWidget *parent) : QMainWindow(parent)
 {
 	setAttribute(Qt::WA_Maemo5StackedWindow);
+        setWindowTitle("System Event Scheduler");
 	
 	QWidget *w = new QWidget(this);
 	this->setCentralWidget(w);
@@ -24,6 +25,13 @@ MainWidget::MainWidget(QWidget *parent) : QMainWindow(parent)
         connect(m_view, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(contextMenu(const QPoint&)));
         layout->addWidget(m_view);
 
+        QMenuBar *bar = new QMenuBar(0);
+        QAction *adv = new QAction(tr("Delete..."), 0x0);
+        connect(adv, SIGNAL(triggered()), this, SLOT(DelAlarm()));
+        bar->addAction(adv);
+        setMenuBar(bar);
+
+
         refreshList();
 }
 
